Options
=======

The following classes define the configuration options for Pty-chi reconstructions.

Base Options
------------

.. autoclass:: ptychi.api.options.base.Options
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.TaskOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ObjectOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ProbeOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ProbePositionOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.OPRModeWeightsOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.FeatureOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.SynthesisDictLearnProbeOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.PositionCorrectionOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.PositionAffineTransformConstraintOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ProbePositionMagnitudeLimitOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ForwardModelOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ObjectMultisliceRegularizationOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ObjectL1NormConstraintOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ObjectL2NormConstraintOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ObjectSmoothnessConstraintOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ObjectTotalVariationOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.RemoveGridArtifactsOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.RemoveObjectProbeAmbiguityOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.SliceSpacingOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ProbePowerConstraintOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ProbeOrthogonalizeIncoherentModesOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ProbeOrthogonalizeOPRModesOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ProbeSupportConstraintOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.ProbeCenterConstraintOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.base.OPRModeWeightsSmoothingOptions
   :members:
   :undoc-members:
   :show-inheritance:

Data Options
------------

.. autoclass:: ptychi.api.options.data.PtychographyDataOptions
   :members:
   :undoc-members:
   :show-inheritance:

Difference Map (DM) Options
---------------------------

.. autoclass:: ptychi.api.options.dm.DMOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.dm.DMReconstructorOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.dm.DMObjectOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.dm.DMProbeOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.dm.DMProbePositionOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.dm.DMOPRModeWeightsOptions
   :members:
   :undoc-members:
   :show-inheritance:

PIE Options
-----------

.. autoclass:: ptychi.api.options.pie.PIEOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.pie.PIEReconstructorOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.pie.PIEObjectOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.pie.PIEProbeOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.pie.PIEProbePositionOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.pie.PIEOPRModeWeightsOptions
   :members:
   :undoc-members:
   :show-inheritance:

LSQML Options
-------------

.. autoclass:: ptychi.api.options.lsqml.LSQMLOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.lsqml.LSQMLReconstructorOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.lsqml.LSQMLObjectOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.lsqml.LSQMLProbeOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.lsqml.LSQMLProbePositionOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.lsqml.LSQMLOPRModeWeightsOptions
   :members:
   :undoc-members:
   :show-inheritance:

Autodiff Ptychography Options
-----------------------------

.. autoclass:: ptychi.api.options.ad_ptychography.AutodiffPtychographyOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.ad_ptychography.AutodiffPtychographyReconstructorOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.ad_ptychography.AutodiffPtychographyObjectOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.ad_ptychography.AutodiffPtychographyProbeOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.ad_ptychography.AutodiffPtychographyProbePositionOptions
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ptychi.api.options.ad_ptychography.AutodiffPtychographyOPRModeWeightsOptions
   :members:
   :undoc-members:
   :show-inheritance: 